@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
+from tempfile import gettempdir
 
 import pytest
 
 from clu.constants.enums import System
 from clu.fs import AppDirs, Directory
+from clu.fs.appdirectories import UnusedValueWarning # ?!
 from clu.version import VersionInfo
 
 XDGS = ('XDG_CONFIG_DIRS', 'XDG_DATA_HOME',
@@ -13,24 +15,6 @@ XDGS = ('XDG_CONFIG_DIRS', 'XDG_DATA_HOME',
                           'XDG_STATE_HOME',
                          'XDG_RUNTIME_DIR')
 
-@pytest.fixture
-def environment(keys=XDGS):
-    """ Yield an instance of `os.environ` free of XDG variables """
-    import os
-    stash = {}
-    
-    # Setup: remove XDG variables from environment:
-    for key in keys:
-        if key in os.environ:
-            stash[key] = os.environ.get(key)
-            del os.environ[key]
-    
-    yield os.environ
-    
-    # Teardown: restore environment:
-    for key, value in stash.items():
-        os.environ[key] = value
-
 class TestFsAppdirectories(object):
     
     """ Run the tests for the clu.fs.appdirectories module. """
@@ -41,7 +25,7 @@ class TestFsAppdirectories(object):
     appversion = "1.2.4"
     
     def test_LINUX_yes_version_no_author(self, environment):
-        home = environment.get('HOME', '/tmp')
+        home = environment.get('HOME', gettempdir())
         appname = type(self).appname
         appversion = type(self).appversion
         appdirs = AppDirs(appname, version=appversion, system=System.LINUX)
@@ -73,11 +57,15 @@ class TestFsAppdirectories(object):
         assert str(appdirs.version_info) == str(VersionInfo(appversion))
     
     def test_LINUX_yes_version_yes_author(self, environment):
-        home = environment.get('HOME', '/tmp')
+        home = environment.get('HOME', gettempdir())
         appname = type(self).appname
         appauthor = type(self).appauthor
         appversion = type(self).appversion
-        appdirs = AppDirs(appname, appauthor, version=appversion, system=System.LINUX)
+        
+        with pytest.warns(UnusedValueWarning):
+            appdirs = AppDirs(appname, appauthor,
+                               version=appversion,
+                                system=System.LINUX)
         
         for xdg in XDGS:
             assert xdg not in environment
@@ -106,7 +94,7 @@ class TestFsAppdirectories(object):
         assert str(appdirs.version_info) == str(VersionInfo(appversion))
     
     def test_LINUX_no_version_no_author(self, environment):
-        home = environment.get('HOME', '/tmp')
+        home = environment.get('HOME', gettempdir())
         appname = type(self).appname
         appdirs = AppDirs(appname, system=System.LINUX)
         
@@ -136,10 +124,13 @@ class TestFsAppdirectories(object):
         assert appdirs.version_info     == None
     
     def test_LINUX_no_version_yes_author(self, environment):
-        home = environment.get('HOME', '/tmp')
+        home = environment.get('HOME', gettempdir())
         appname = type(self).appname
         appauthor = type(self).appauthor
-        appdirs = AppDirs(appname, appauthor, system=System.LINUX)
+        
+        with pytest.warns(UnusedValueWarning):
+            appdirs = AppDirs(appname, appauthor,
+                                system=System.LINUX)
         
         for xdg in XDGS:
             assert xdg not in environment
@@ -167,10 +158,11 @@ class TestFsAppdirectories(object):
         assert appdirs.version_info     == None
     
     def test_LINUX2_yes_version_no_author(self, environment):
-        home = environment.get('HOME', '/tmp')
+        home = environment.get('HOME', gettempdir())
         appname = type(self).appname
         appversion = type(self).appversion
-        appdirs = AppDirs(appname, version=appversion, system=System.LINUX2)
+        appdirs = AppDirs(appname, version=appversion,
+                                    system=System.LINUX2)
         
         for xdg in XDGS:
             assert xdg not in environment
@@ -199,11 +191,15 @@ class TestFsAppdirectories(object):
         assert str(appdirs.version_info) == str(VersionInfo(appversion))
     
     def test_LINUX2_yes_version_yes_author(self, environment):
-        home = environment.get('HOME', '/tmp')
+        home = environment.get('HOME', gettempdir())
         appname = type(self).appname
         appauthor = type(self).appauthor
         appversion = type(self).appversion
-        appdirs = AppDirs(appname, appauthor, version=appversion, system=System.LINUX2)
+        
+        with pytest.warns(UnusedValueWarning):
+            appdirs = AppDirs(appname, appauthor,
+                               version=appversion,
+                                system=System.LINUX2)
         
         for xdg in XDGS:
             assert xdg not in environment
@@ -232,7 +228,7 @@ class TestFsAppdirectories(object):
         assert str(appdirs.version_info) == str(VersionInfo(appversion))
     
     def test_LINUX2_no_version_no_author(self, environment):
-        home = environment.get('HOME', '/tmp')
+        home = environment.get('HOME', gettempdir())
         appname = type(self).appname
         appdirs = AppDirs(appname, system=System.LINUX2)
         
@@ -262,10 +258,13 @@ class TestFsAppdirectories(object):
         assert appdirs.version_info     == None
     
     def test_LINUX2_no_version_yes_author(self, environment):
-        home = environment.get('HOME', '/tmp')
+        home = environment.get('HOME', gettempdir())
         appname = type(self).appname
         appauthor = type(self).appauthor
-        appdirs = AppDirs(appname, appauthor, system=System.LINUX2)
+        
+        with pytest.warns(UnusedValueWarning):
+            appdirs = AppDirs(appname, appauthor,
+                                system=System.LINUX2)
         
         for xdg in XDGS:
             assert xdg not in environment
@@ -296,7 +295,8 @@ class TestFsAppdirectories(object):
         user = environment.get('USER', 'nobody')
         appname = type(self).appname
         appversion = type(self).appversion
-        appdirs = AppDirs(appname, version=appversion, system=System.DARWIN)
+        appdirs = AppDirs(appname, version=appversion,
+                                    system=System.DARWIN)
         
         for xdg in XDGS:
             assert xdg not in environment
@@ -329,7 +329,11 @@ class TestFsAppdirectories(object):
         appname = type(self).appname
         appauthor = type(self).appauthor
         appversion = type(self).appversion
-        appdirs = AppDirs(appname, appauthor, version=appversion, system=System.DARWIN)
+        
+        with pytest.warns(UnusedValueWarning):
+            appdirs = AppDirs(appname, appauthor,
+                               version=appversion,
+                                system=System.DARWIN)
         
         for xdg in XDGS:
             assert xdg not in environment
@@ -391,7 +395,10 @@ class TestFsAppdirectories(object):
         user = environment.get('USER', 'nobody')
         appname = type(self).appname
         appauthor = type(self).appauthor
-        appdirs = AppDirs(appname, appauthor, system=System.DARWIN)
+        
+        with pytest.warns(UnusedValueWarning):
+            appdirs = AppDirs(appname, appauthor,
+                                system=System.DARWIN)
         
         for xdg in XDGS:
             assert xdg not in environment
